<?php
namespace Vimeo\Media\Ingester;

use Omeka\Api\Request;
use Omeka\Entity\Media;
use Omeka\Media\Ingester\IngesterInterface;
use Omeka\Stdlib\ErrorStore;
use Omeka\File\Downloader;
use Zend\Form\Element\Text;
use Zend\Http\Client;
use Zend\View\Renderer\PhpRenderer;

class VimeoMediaIngester implements IngesterInterface
{

    /**
     * @var Downloader
     */
    protected $downloader;
    protected $client;

    public function __construct($client, Downloader $downloader)
    {
        $this->client = $client;
        $this->downloader = $downloader;
    }
    public function getLabel()
    {
        return 'Vimeo model'; // @translate
    }
    public function getRenderer()
    {
        return 'Vimeo_media';
    }
    public function form(PhpRenderer $view, array $options = [])
    {
        $input = new Text('o:media[__index__][o:identifier]');
        $input->setOptions([
            'label' => 'URL of the video', // @translate
        ]);
        $input->setAttributes([
            'required' => true,
            'placeholder' => 'https://vimeo.com/....',
        ]);
        return $view->formRow($input);
    }
    public function ingest(Media $media, Request $request, ErrorStore $errorStore)
    {
        // Validate the request data.
        $data = $request->getContent();
        if (!isset($data['o:identifier'])) {
            $errorStore->addError('o:identifier', 'No identifier specified');
            return;
        }
        $identifier = trim($data['o:identifier']);
        $url = 'https://vimeo.com/api/oembed.json?url=' . $identifier;
        $response = $this->client->setUri($url)->send();
        if (!$response->isOk()) {
                    $errorStore->addError('o:source', sprintf(
                        'Cannot find video URL: ' . $identifier,
                        $response->getReasonPhrase(),
                        $response->getStatusCode()
                    ));
                    return false;
        }
        $response_body = json_decode($response->getBody());
        $thumbnail_url = $response_body->thumbnail_url;
        $tempFile = $this->downloader->download($thumbnail_url);
        if ($tempFile) {
            $tempFile->mediaIngestFile($media, $request, $errorStore, false);
        }

        // Set the Media source and data.
        $media->setSource($data['o:source']);
        $media->setData(json_decode($response->getBody(), true));
    }
}
